==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/realm/entity/MapClientInitialAccessEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapClientInitialAccessEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> entityFieldDelegate;
    public MapClientInitialAccessEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.COUNT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getRemainingCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.REMAINING_COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setRemainingCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.REMAINING_COUNT, p0);
    }
}

==> keycloak-model-map-22.0.5-sources.jar: org/keycloak/models/map/realm/entity/MapClientInitialAccessEntityFieldDelegate.java <==
package org.keycloak.models.map.realm.entity;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapClientInitialAccessEntityFieldDelegate extends org.keycloak.models.map.common.UpdatableEntity.Impl implements org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> entityFieldDelegate;
    public MapClientInitialAccessEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.realm.entity.MapClientInitialAccessEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void markUpdatedFlag() {
        entityFieldDelegate.markUpdatedFlag();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @Override public String toString() {
        return "%" + String.valueOf(entityFieldDelegate);
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getTimestamp() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.TIMESTAMP);
    }
    @SuppressWarnings("unchecked") @Override public void setTimestamp(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.TIMESTAMP, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.COUNT, p0);
    }
    @SuppressWarnings("unchecked") @Override public Integer getRemainingCount() {
        return (Integer) entityFieldDelegate.get(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.REMAINING_COUNT);
    }
    @SuppressWarnings("unchecked") @Override public void setRemainingCount(Integer p0) {
        entityFieldDelegate.set(org.keycloak.models.map.realm.entity.MapClientInitialAccessEntityFields.REMAINING_COUNT, p0);
    }
}
